django-comments-dab
===================

.. image:: https://badge.fury.io/py/django-comments-dab.svg
    :target: https://pypi.org/project/django-comments-dab/

.. image:: https://badge.fury.io/gh/radi85%2FComment.svg
    :target: https://github.com/Radi85/Comment/releases

.. image:: https://travis-ci.org/Radi85/Comment.svg?branch=master
    :target: https://travis-ci.org/Radi85/Comment

.. image:: https://coveralls.io/repos/github/Radi85/Comment/badge.svg
    :target: https://coveralls.io/github/Radi85/Comment

.. image:: https://img.shields.io/pypi/pyversions/django-comments-dab.svg
   :target: https://pypi.python.org/pypi/django-comments-dab/

.. image:: https://img.shields.io/pypi/djversions/django-comments-dab.svg
   :target: https://pypi.python.org/pypi/django-comments-dab/

.. image:: https://readthedocs.org/projects/django-comment-dab/badge/?version=latest
    :target: https://django-comment-dab.readthedocs.io/?badge=latest

.. image:: https://img.shields.io/github/contributors/radi85/Comment
    :target: https://github.com/Radi85/Comment/graphs/contributors

.. image:: https://img.shields.io/github/license/radi85/Comment?color=gr
    :target: https://github.com/Radi85/Comment/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/dm/django-comments-dab


.. image:: ../_static/img/comment.gif

Introduction
============

**dab stands for Django-Ajax-Bootstrap**

``django-comments-dab`` is a commenting application for Django-powered
websites.

It allows you to integrate commenting functionality with any model you have e.g. blogs, pictures, video etc…

*List of actions the authenticated user can do:*

    1. Post a new comment.

    2. Reply to an existing comment.

    3. Edit a comment.

    4. Delete a comment.

    5. React to a comment. Available reactions are LIKE and DISLIKE  # open PR if you would like to have more reactions


- All actions are done by AJAX calls - JQuery 3.2.1

- Bootstrap 4.1.1 is used in comment templates for responsive design.